@@ -1,25 +1,26 @@
+from zoneinfo import ZoneInfo
+
+from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.db import models
-from django.utils import timezone
 from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
 from edc_model.validators import datetime_not_future
 from edc_model_fields.fields import OtherCharField
 from edc_protocol.validators import datetime_not_before_study_start
-from edc_utils import formatted_datetime, get_utcnow
+from edc_utils import convert_php_dateformat, get_utcnow
+from edc_visit_schedule.utils import (
+    off_all_schedules_or_raise,
+    offstudy_datetime_after_all_offschedule_datetimes,
+)
 
 from ..choices import OFFSTUDY_REASONS
-from ..utils import off_all_schedules_or_raise
+from ..utils import OffstudyError
 
 
 class OffstudyModelMixinError(ValidationError):
     pass
 
 
-class OffstudyModelManager(models.Manager):
-    def get_by_natural_key(self, subject_identifier):
-        return self.get(subject_identifier=subject_identifier)
-
-
 class OffstudyModelMixin(UniqueSubjectIdentifierFieldMixin, models.Model):
     """Model mixin for the Off-study model.
 
@@ -40,6 +41,8 @@ class OffstudyModelMixin(UniqueSubjectIdentifierFieldMixin, models.Model):
         default=get_utcnow,
     )
 
+    report_datetime = models.DateTimeField(null=True, editable=False)
+
     offstudy_reason = models.CharField(
         verbose_name="Please code the primary reason participant taken off-study",
         choices=offstudy_reason_choices,
@@ -56,22 +59,25 @@ class OffstudyModelMixin(UniqueSubjectIdentifierFieldMixin, models.Model):
     )
 
     def __str__(self):
-        local = timezone.localtime(self.offstudy_datetime)
-        return f"{self.subject_identifier} {formatted_datetime(local)}"
+        dte_str = self.report_datetime.astimezone(ZoneInfo(settings.TIME_ZONE)).strftime(
+            convert_php_dateformat(settings.SHORT_DATETIME_FORMAT)
+        )
+        return f"{self.subject_identifier} {dte_str}"
 
     def save(self, *args, **kwargs):
-        off_all_schedules_or_raise(
+        self.report_datetime = self.offstudy_datetime
+        datetime_not_before_study_start(self.offstudy_datetime)
+        datetime_not_future(self.offstudy_datetime)
+        off_all_schedules_or_raise(subject_identifier=self.subject_identifier)
+        offstudy_datetime_after_all_offschedule_datetimes(
             subject_identifier=self.subject_identifier,
             offstudy_datetime=self.offstudy_datetime,
+            exception_cls=OffstudyError,
         )
         super().save(*args, **kwargs)
 
     def natural_key(self):
         return (self.subject_identifier,)
 
-    @property
-    def report_datetime(self):
-        return self.offstudy_datetime
-
     class Meta:
         abstract = True
